@@ -6,6 +6,8 @@ import pytest
 import arbejdstimer.arbejdstimer as at
 from arbejdstimer import date_from_fractional_year, day_count, day_count_from_date, fractional_year_from_date
 
+TODAY = dti.date.today().strftime('%Y-%m-%d')
+
 
 def _subs(count: int, what: str) -> str:
     """DRY."""
@@ -13,26 +15,26 @@ def _subs(count: int, what: str) -> str:
 
 
 def test_at_main_now():
-    assert at.main(['now', str(fix.CFG_FS_HOLIDAYS)]) in (0, 1)
+    assert at.main(['now', '', str(fix.CFG_FS_HOLIDAYS)]) in (0, 1)
 
 
 def test_at_main_now_meta_only():
-    assert at.main(['now', str(fix.CFG_FS_META_ONLY)]) in (0, 1)
+    assert at.main(['now', '', str(fix.CFG_FS_META_ONLY)]) == 2
 
 
 def test_at_main_now_load_error_processing(capsys):
-    assert at.main(['now', str(fix.CFG_FS_INVALID_MINIMAL)]) == 2
+    assert at.main(['now', '', str(fix.CFG_FS_INVALID_MINIMAL)]) == 2
     out, err = capsys.readouterr()
     assert not out
     assert not err
 
 
 def test_at_main_explain():
-    assert at.main(['explain', str(fix.CFG_FS_HOLIDAYS)]) in (0, 1)
+    assert at.main(['explain', '', str(fix.CFG_FS_HOLIDAYS)]) in (0, 1)
 
 
 def test_at_main_explain_load_error_processing(capsys):
-    assert at.main(['explain', str(fix.CFG_FS_INVALID_MINIMAL)]) == 2
+    assert at.main(['explain', '', str(fix.CFG_FS_INVALID_MINIMAL)]) == 2
     out, err = capsys.readouterr()
     assert 'Configuration file failed to parse (INVALID)' in out
     message_part = (
@@ -47,17 +49,20 @@ def test_at_verify_request_too_few():
 
 
 def test_at_verify_request_unknown_command():
-    assert at.verify_request(['unknown', 'does not matter']) == (2, 'received unknown command', [''])
+    assert at.verify_request(['unknown', '', 'does not matter']) == (2, 'received unknown command', [''])
 
 
 def test_at_verify_request_falsy_input():
-    assert at.verify_request(['now', '']) == (2, 'configuration missing', [''])
+    assert at.verify_request(['now', '', '']) == (2, 'configuration missing', [''])
 
 
 def test_at_main_holidays(capsys):
-    assert at.main(['explain', str(fix.CFG_FS_HOLIDAYS)]) in (0, 1)
+    assert at.main(['explain', '2022-10-22', str(fix.CFG_FS_HOLIDAYS)]) in (0, 1)
     out, err = capsys.readouterr()
-    assert 'consider 11 holidays' in out.lower()
+    assert 'consider 12 holidays' in out.lower()
+    assert 'is within date range of configuration' in out.lower()
+    assert 'is not a holiday' in out.lower()
+    assert 'is weekend.' in out.lower()
     assert not err
 
 
@@ -192,7 +197,8 @@ def test_at_load_and_apply_today_holiday(capsys):
     error, message, holidays, _ = at.load(fix.CFG_PY_TODAY_HOLIDAY)
     assert not error
     assert not message
-    assert at.apply(holidays, (None, None), 'explain') == (1, '- Day is a holiday.')
+    expected = (2, '- Day is not within year range of configuration')
+    assert at.apply(holidays, (None, None), 'explain', TODAY) == expected
     out, err = capsys.readouterr()
     assert not out
     assert not err
@@ -209,38 +215,37 @@ def test_at_load_triplet_holidays():
 def test_at_apply_now_monday_noon():
     at.weekday = fix.always_monday
     at.the_hour = fix.the_noon_hour
-    assert at.apply([], at.DEFAULT_WORK_HOURS_MARKER, 'now') == (0, '')
+    assert at.apply([], at.DEFAULT_WORK_HOURS_MARKER, 'now', TODAY) == (2, '- empty date range of configuration')
 
 
 def test_at_apply_now_sunday_noon():
     at.weekday = fix.always_sunday
     at.the_hour = fix.the_noon_hour
-    error, message = at.apply([], at.DEFAULT_WORK_HOURS_MARKER, 'now')
-    assert error == 1
-    assert message == '- Day is weekend.'
+    error, message = at.apply([dti.date.today()], at.DEFAULT_WORK_HOURS_MARKER, 'now', TODAY)
+    assert error == 2
+    assert message == '- Day is not within year range of configuration'
 
 
 def test_at_apply_now_monday_midnight():
     at.weekday = fix.always_monday
     at.the_hour = fix.the_zero_hour
-    assert at.apply([], at.DEFAULT_WORK_HOURS_MARKER, 'now') == (1, f'- No worktime at hour({at.the_hour()}).')
+    assert at.apply([], at.DEFAULT_WORK_HOURS_MARKER, 'now', TODAY) == (2, '- empty date range of configuration')
 
 
 def test_at_apply_now_sunday_midnight():
     at.weekday = fix.always_sunday
     at.the_hour = fix.the_zero_hour
-    error, message = at.apply([], at.DEFAULT_WORK_HOURS_MARKER, 'now')
-    assert error == 1
-    assert message == '- Day is weekend.'
+    error, message = at.apply([dti.date.today()], at.DEFAULT_WORK_HOURS_MARKER, 'now', TODAY)
+    assert error == 2
+    assert message == '- Day is not within year range of configuration'
 
 
 def test_at_apply_explain_monday_noon(capsys):
     at.weekday = fix.always_monday
     at.the_hour = fix.the_noon_hour
-    assert at.apply([], at.DEFAULT_WORK_HOURS_MARKER, 'explain') == (0, '')
+    expected = (2, '- Day is not within year range of configuration')
+    assert at.apply([dti.date.today()], at.DEFAULT_WORK_HOURS_MARKER, 'explain', TODAY) == expected
     out, err = capsys.readouterr()
-    assert f'- Day ({fix.TODAY}) is not a holiday' in out
-    assert f'- At this hour ({at.the_hour()}) is work time' in out
     assert not err
 
 
